@@ -1,10 +1,17 @@
 def start():
     try:
-        from simple_server import run
-        run(9889)
+        import simple_server
     except:
         import traceback
         traceback.print_exc()
+        reload(simple_server)
+    else:
+        try:
+            simple_server.run(9889)
+        except:
+            import traceback
+            traceback.print_exc()
+        
 
 from time import sleep
 from mypy.reload_server import auto_reload
