@@ -13,17 +13,17 @@ from myconf.config import MEMCACHED_ADDR,DISABLE_LOCAL_CACHED
 from sqlbean.db.mc_connection import init_mc
 init_mc(memcached_addr=MEMCACHED_ADDR,disable_local_cached=DISABLE_LOCAL_CACHED)
 
-from sqlbean.db.sqlstore import SqlStore
-from myconf.config import DATABASE_CONFIG
 
-SQLSTORE = SqlStore(db_config=DATABASE_CONFIG, **{})
+from myconf.config import DATABASE_CONFIG,THREAD_SAFE
+from sqlbean.db import connection
+connection.THREAD_SAFE = THREAD_SAFE
 
+from sqlbean.db import sqlstore
+SQLSTORE = sqlstore.SqlStore(db_config=DATABASE_CONFIG, **{})
 def get_db_by_table(table_name):
     return SQLSTORE.get_db_by_table(table_name)
-
-
-from sqlbean.db import connection
 connection.get_db_by_table = get_db_by_table
 
-
 from sqlbean.shortcut import Query,mc,MMcCache,McCache,ForeignKey,OneToMany,Model,McModel
+
+
